@@ -16,8 +16,16 @@ def get_ou_id(event):
 
 def on_event(event, context):  
   print(event)
-  allow_recreate_on_update = True if event['ResourceProperties']['AllowRecreateOnUpdate'] == "true" else False
-  import_on_duplicate = True if event['ResourceProperties']['ImportOnDuplicate'] == "true" else False
+  allow_recreate_on_update = False
+  import_on_duplicate = False
+  try:
+    allow_recreate_on_update = True if event['ResourceProperties']['AllowRecreateOnUpdate'] == "true" else False
+  except KeyError as e:
+    print('No AllowRecreateOnUpdate property found. Defaulting to false')
+  try:
+    import_on_duplicate = True if event['ResourceProperties']['ImportOnDuplicate'] == "true" else False
+  except KeyError as e:
+    print('No ImportOnDuplicate property found. Defaulting to false')
 
   request_type = event['RequestType']
   if request_type == 'Create': return on_create(event, import_on_duplicate)
@@ -116,13 +124,6 @@ def on_delete(event):
         }
       }
     if e.response['Error']['Code'] == 'OrganizationalUnitNotEmptyException':
-      msg = 'OU has children and cannot be deleted: {}'.format(event['ResourceProperties']['Name'])
-      print(msg)
-      return {
-        'PhysicalResourceId': event['PhysicalResourceId'],
-        'Data': {
-          'Message': msg
-        }
-      }
+      raise Exception('OU has children and cannot be deleted: {}'.format(event['ResourceProperties']['Name']))
     else:
       raise e
